@@ -70,7 +70,19 @@ cell2bool(lex_ctxt* lexic, tree_cell* c)
       if (c->size == 0)
 	return 0;
       if(c->x.str_val[0] == '0' && c->size == 1)
+	{
+	  /* 
+	   * This gives the same semantics as Perl ("0" is false), 
+	   * but I do not agree with it. 
+	   * This piece of code is here from the begining of NASL2; it 
+	   * probably fixed some compatibility issue with old 
+	   * quick & dirty scripts. 
+	   * I added this warning to check if we can switch to a
+	   * simpler behaviour (empty string = false, not empty = true)
+	   */
+	  nasl_perror(lexic, "cell2boll: string '0' is FALSE\n");
 	  return 0;
+	}
      return 1;
 
     case REF_ARRAY:
@@ -1313,7 +1325,7 @@ nasl_exec(lex_ctxt* lexic, tree_cell* st)
 	{
 	case CONST_INT:
 	  x = tc1->x.i_val;
-	  y = cell2int(lexic, st->link[1]);
+	  y = cell2int(lexic, tc2);
 	  ret = int2cell(x + y);
 	  break;
 
