@@ -168,7 +168,7 @@ tree_cell * nasl_telnet_init(lex_ctxt * lexic)
    n += n2;
  retc = alloc_typed_cell(CONST_DATA);
  retc->size = n;
- retc->x.str_val = nasl_strndup(buffer, n);
+ retc->x.str_val = nasl_strndup((char*)buffer, n);
 #undef iac
 #undef data
 #undef option
@@ -471,7 +471,7 @@ nasl_keys(lex_ctxt* lexic)
 		if (vn->u.var_type != VAR2_UNDEF)
 		  {
 		    myvar.var_type = VAR2_STRING;
-		    myvar.v.v_str.s_val = vn->var_name;
+		    myvar.v.v_str.s_val = (unsigned char*)vn->var_name;
 		    myvar.v.v_str.s_siz = strlen(vn->var_name);
 		    add_var_to_list(a2, i ++, &myvar);
 		  }
@@ -598,7 +598,7 @@ nasl_func_named_args(lex_ctxt* lexic)
 
   for (i = 0; i < f->nb_named_args; i ++)
     {
-      v.v.v_str.s_val = f->args_names[i];
+      v.v.v_str.s_val = (unsigned char*)f->args_names[i];
       v.v.v_str.s_siz = strlen(f->args_names[i]);
       if (add_var_to_list(a, i, &v) < 0)
 	nasl_perror(lexic, "func_named_args: add_var_to_list failed (internal error)\n");
