@@ -1165,19 +1165,14 @@ tree_cell * nasl_tcp_ping(lex_ctxt * lexic)
  int i = 0;
  int bpf;
  char filter[255];
- struct ip * pk = NULL;
+ u_char * pk = NULL;
  tree_cell * retc;
  int opt = 1;
+ struct timeval tv;
+ int len;
 #define rnd_tcp_port() (rand() % 65535 + 1024)
-
- 
- 
  int sports[]= { 0,     0,   0,  0,  0, 1023, 0,  0,    0,    0,  0,   0,    0,    0,    0,  0,   0,   0,    0,    0, 53,   0,    0,    20,   0,  25,   0,    0, 0};
  int ports[] = { 139, 135, 445, 80, 22, 515, 23, 21, 6000, 1025, 25, 111, 1028, 9100, 1029, 79, 497, 548, 5000, 1917, 53, 161, 9001, 65535, 443, 113, 993, 8080, 0};
- 
- 
- 
- 
  int num_ports = 0;
  
  
@@ -1265,8 +1260,9 @@ tree_cell * nasl_tcp_ping(lex_ctxt * lexic)
  soca.sin_family = AF_INET;
  soca.sin_addr = ip->ip_dst;
  sendto(soc, (const void*)ip, 40, 0, (struct sockaddr *)&soca, sizeof(soca));
- if(bpf >= 0 && (pk = capture_next_packet(bpf, 0, NULL)))flag++;	
- i++;
+ tv.tv_sec = 0;
+ tv.tv_usec = 100000;
+ if(bpf >= 0 && (pk = bpf_next_tv(bpf, &len, &tv)))flag++;	
   }
  }
 
@@ -1308,6 +1304,8 @@ tree_cell*	nasl_send_packet(lex_ctxt* lexic)
  if(setsockopt(soc, IPPROTO_IP, IP_HDRINCL, (char*)&i, sizeof(i))<0)
 	perror("setsockopt ");
 #endif
+
+
  
   while ((ip = get_str_var_by_num(lexic, vi)) != NULL)
     {
@@ -1321,9 +1319,9 @@ tree_cell*	nasl_send_packet(lex_ctxt* lexic)
       }
       
       sip = (struct ip *)ip;
-     
       if( use_pcap != 0 && bpf < 0)
 	bpf = init_capture_device(sip->ip_dst, sip->ip_src, filter);
+     
 
       bzero(&sockaddr, sizeof(struct sockaddr_in));
       sockaddr.sin_family = AF_INET;
