@@ -964,7 +964,16 @@ nasl_split(lex_ctxt* lexic)
 
   sep = get_str_local_var_by_name(lexic, "sep");
   if (sep != NULL)
+    {
     sep_len = get_var_size_by_name(lexic, "sep");
+    if ( sep_len <= 0 ) sep_len = strlen(sep);
+    if ( sep_len <= 0 ) 
+	{
+      	   nasl_perror(lexic, "split: invalid 'seplen' parameter\n");
+	   return NULL;
+	}
+    }
+
   keep = get_int_local_var_by_name(lexic, "keep", 1);
 
   retc = alloc_tree_cell(0, NULL);
