@@ -516,7 +516,9 @@ copy_anon_var(anon_nasl_var* v1, const anon_nasl_var *v2)
       break;
 
     case VAR2_ARRAY:
-      /* TBD: handle arrays here for multi-dimensional arrays */
+      copy_array(&v1->v.v_arr, &v2->v.v_arr, 0);
+      break;
+
     default:
       nasl_perror(NULL, "copy_anon_var: unhandled type 0x%x\n", v2->var_type);
       clear_anon_var(v1);
